-- displayLights.lua
-- Script for Fendt Favorit 622 LS
--
-- Author RivalBomb
-- 13.08.2016

displayLights = {};

function displayLights.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function displayLights:load(xmlFile)
	self.blinkerLight0 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.displayLights.blinkerLight#index0"));
	self.blinkerLight1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.displayLights.blinkerLight#index1"));
	self.blinkerLight2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.displayLights.blinkerLight#index2"));
	self.rulLight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.displayLights.rulLight#index"));
	self.blinkerLightActive = false;
	self.mFlickeringS = 0;
	self.hasAttachedTrailers = 0;
	setVisibility(self.blinkerLight0, false);
	setVisibility(self.blinkerLight1, false);
	setVisibility(self.blinkerLight2, false);
	setVisibility(self.rulLight, false);
end;
function displayLights:delete()
end;
function displayLights:mouseEvent(posX, posY, isDown, isUp, button)
end;
function displayLights:keyEvent(unicode, sym, modifier, isDown)
end;
function displayLights:update(dt)
	if self:getIsActive() and self.isClient then
		local mFlickering = math.floor((getShaderTimeSec()*7*2 + math.acos(-0.2)) / (math.pi*2));
		if mFlickering ~= self.mFlickeringS then
			self.blinkerLightActive = not self.blinkerLightActive;
			self.mFlickeringS = mFlickering;
		end;
		if table.getn(self.attachedImplements) > 0 or self.hasAttachedTrailers > 0 then
			self.hasAttachedTrailers = 0;
			for i=1, table.getn(self.attachedImplements) do  
				if #self.attachedImplements[i].object.turnSignals.left > 0 and #self.attachedImplements[i].object.turnSignals.right > 0 then 
					self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
				end;
				if table.getn(self.attachedImplements[i].object.attachedImplements) > 0 then
					for r=1, table.getn(self.attachedImplements[i].object.attachedImplements) do
						if #self.attachedImplements[i].object.attachedImplements[r].object.turnSignals.left > 0 and #self.attachedImplements[i].object.attachedImplements[r].object.turnSignals.right > 0 then
							self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
						end;
					end;
				end;
			end;
		end;
		if self.hasAttachedTrailers == 0 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, false);
			setVisibility(self.blinkerLight2, false);
		elseif self.hasAttachedTrailers == 1 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight2, false);
		elseif self.hasAttachedTrailers == 2 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight2, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
		end;
		setVisibility(self.rulLight, self.beaconLightsActive);
	end;
end;
function displayLights:updateTick(dt)
end;
function displayLights:draw()	
end;